@@ -33,6 +33,7 @@
 #include <grantlee/plaintextmarkupbuilder.h>
 
 #include <KActionCollection>
+#include <QAction>
 #include <QFileInfo>
 #include <QMimeData>
 
@@ -95,6 +96,13 @@ QList<QAction *> RichTextComposer::richTextActionList() const
     return d->richTextComposerActions->richTextActionList();
 }
 
+void RichTextComposer::setEnableActions(bool state)
+{
+    Q_FOREACH (QAction *act, richTextActionList()) {
+        act->setEnabled(state);
+    }
+}
+
 void RichTextComposer::createActions(KActionCollection *ac)
 {
     d->richTextComposerActions->createActions(ac);
@@ -526,7 +534,6 @@ bool RichTextComposer::canInsertFromMimeData(const QMimeData *source) const
     return KPIMTextEdit::RichTextEditor::canInsertFromMimeData(source);
 }
 
-
 void RichTextComposer::mouseReleaseEvent(QMouseEvent *event)
 {
     if (d->composerControler->painterActive()) {
